@@ -24,7 +24,7 @@ from libinsitu.log import warning
 
 # Name of dimensions and variables
 TIME_DIM = 'time'
-TIME_VAR = "Time"
+TIME_VAR = "time"
 GLOBAL_VAR = "GHI"
 DIFFUSE_VAR = "DHI"
 DIRECT_VAR = "BNI"
@@ -202,10 +202,10 @@ def to_int(vals) :
     else:
         return int(vals)
 
-def datetime64_to_sec(ncfile, dates : NDArray[datetime64]) -> NDArray[int] :
+def datetime64_to_sec(ncfile, dates : NDArray[datetime64], unit='s') -> NDArray[int] :
     """Transform datetime64 to number of seconds since origin date """
     origin = get_origin_time(ncfile)
-    return to_int((dates - origin) / SECOND)
+    return to_int((dates - origin) / timedelta64(1, unit))
 
 def str_to_date64(datestr) :
     for format in [TIME_FORMAT_SEC, TIME_FORMAT_MIN, DATE_FORMAT] :
@@ -221,10 +221,12 @@ def start_date64(ncfile) :
     if  hasattr(ncfile, STATION_START_DATA_ATTR) :
         return str_to_date64(getattr(ncfile, STATION_START_DATA_ATTR))
     else:
-        res = sec_to_datetime64(ncfile, ncfile[TIME_VAR][0])
+        res = sec_to_datetime64(ncfile, getTimeVar(ncfile)[0])[()]
         warning("No start date set in meta data : taking the first value of ncfile : %s" % res)
         return res
 
+def end_date64(ncfile):
+    return sec_to_datetime64(ncfile, getTimeVar(ncfile)[-1])[()]
 
 def seconds_to_idx(ncfile, dates : NDArray[int], ) -> NDArray[int] :
     """Transform seconds since origin to time idx, taking into account resolution and start date"""
@@ -243,7 +245,7 @@ def read_res(path, encoding="utf8") :
     """
     return get_data(__name__, os.path.join("res", path)).decode(encoding).splitlines()
 
-def parse_value(val) :
+def parse_value(val, split=False) :
     """Parse string value, trying first int, then float. return str value if none are correct"""
     if not isinstance(val, str) :
         return val
@@ -258,7 +260,7 @@ def parse_value(val) :
         return val.strip('"')
 
     # List of things
-    if "," in val :
+    if split and "," in val :
         return list(parse_value(item) for item in val.split(","))
 
     try :
@@ -381,10 +383,12 @@ def match_pattern(pattern, value, properties=dict()) :
 
     return res
 
-
-def nc2df(
+def netcdf_to_dataframe(
         ncfile : Union[Dataset, str],
-        start_time: Union[datetime, datetime64]=None, end_time:Union[datetime, datetime64]=None,
+        start_time: Union[datetime, datetime64]=None,
+        end_time:Union[datetime, datetime64]=None,
+        rel_start_time=None, # Start time, relative to actual end
+        rel_end_time=None, # End time, relative to actual start
         drop_duplicates=True,
         skip_na=False,
         skip_qc=False,
@@ -396,27 +400,33 @@ def nc2df(
         steps=1,
         rename_cols=False) :
     """
-        Load NETCDF in-situ file (or part of it) into a panda Dataframe, with time as index
+        Load NETCDF in-situ file (or part of it) into a panda Dataframe, with time as index.
 
+
+        :param ncfile: NetCDF Dataset or filename, or OpenDAP URL
+        :param rename_cols: If True (default) rename solar irradiance columns as per convention (GHI, BNI, DHI)
+        :param drop_duplicates: If true (default), duplicate rows are droppped
         :param skip_qc: If True, skip lines with bad QC (at least one failing)
-        :param rename_cols: If True (default) rename solar irradiance columns to proper names
-        :param ncfile: NetCDF Dataset or filename, or URL
-        :param drop_duplicates: If true (default), duplicate rows with same time are droppped
-        :param skip_na : If True, drop rows containing only nan values
-        :param start_time: Start time (first one by default) : Datetime or datetime64
-        :param end_time: End time (last one by default) : Datetile or datetime64
-        :param vars: List of columns names to  convert (all by default)
-        :param user: Optional login for URL
-        :param password: Optional password for URL
-        :param chunk_size Size of chunks for chunked data
-        :param steps Downsampling (1 by default)
-        :return: Dataframe or Iterator (yield) of Dataframes
+        :param skip_na: If True, drop rows containing only nan values
+        :param start_time: Start time (first record by default) : Datetime or datetime64
+        :param end_time: End time (last record by default) : Datetile or datetime64
+        :param rel_end_time: End time, relative to actual start time : relativedelta
+        :param rel_start_time: Start time, relatie to actual end time : relativedelta
+        :param vars: List of columns names to convert (all by default)
+        :param user: Optional login for OpenDAP URL
+        :param password: Optional password OpenDAP URL
+        :param chunked: If True, does not load the whole file in memory at once : returns an iterator on Dataframe chunks.
+        :param chunk_size: Size of chunks for chunked data
+        :param steps: Downsampling (1 by default)
+        :return: Pandas Dataframe, or iterator on Dataframes is chunk is activated
         """
 
     chunks = __nc2df(
         ncfile=ncfile,
         start_time=start_time,
         end_time=end_time,
+        rel_start_time=rel_start_time,
+        rel_end_time=rel_end_time,
         drop_duplicates=drop_duplicates,
         skip_na=skip_na,
         vars=vars,
@@ -466,7 +476,10 @@ def __all_attributes(ncfile) :
 
 def __nc2df(
         ncfile : Union[Dataset, str],
-        start_time: Union[datetime, datetime64]=None, end_time:Union[datetime, datetime64]=None,
+        start_time: Union[datetime, datetime64]=None,
+        end_time:Union[datetime, datetime64]=None,
+        rel_start_time=None,
+        rel_end_time=None,
         drop_duplicates=True,
         skip_na=False,
         skip_qc=False,
@@ -485,6 +498,11 @@ def __nc2df(
 
     size = len(timeVar)
 
+    if rel_start_time is not None :
+        start_time = end_date64(ncfile).astype(datetime) + rel_start_time
+    if rel_end_time is not None :
+        end_time = start_date64(ncfile).astype(datetime) + rel_end_time
+
     start_idx = max(0, date_to_timeidx(ncfile, start_time)) if start_time else 0
     end_idx = min(date_to_timeidx(ncfile, end_time), size) if end_time else size
 
@@ -647,24 +665,22 @@ def readShortname(ncfile) :
     # Then read the content of the dedicated var
     return read_str(ncfile.variables[STATION_NAME_VAR])
 
-def getStationId(attrs) :
-    # First try standard attributes
-    for key in STATION_ID_ATTRS :
-        if key in attrs :
-            return attrs[key]
+def getMult(attrs, keys):
+    """Get value of dict or attribute in NCfile, looking several possbilities"""
 
+    if isinstance(attrs, Dataset) :
+        attrs  = dict((attr, getattr(attrs, attr)) for attr in attrs.ncattrs())
+
+    for name in keys:
+        if name in attrs:
+            return attrs[name]
     return None
 
+def getNetworkId(attributes_or_ncfile) :
+    return getMult(attributes_or_ncfile, NETWORK_ID_ATTRS)
 
-def getNetworkId(attributes) :
-    # First try standard attributes
-    for name in NETWORK_ID_ATTRS :
-        if name in attributes :
-            return attributes[name]
-    raise Exception("Network name not found. Tried the following attributes : %s" % str(NETWORK_ID_ATTRS))
-
-
-
+def getStationId(attributes_or_ncfile) :
+    return getMult(attributes_or_ncfile, STATION_ID_ATTRS)
 
 def getProperties(network_id, station_id) :
     """Gather Network_ and Station_ properties """
@@ -679,12 +695,17 @@ def getProperties(network_id, station_id) :
     return properties
 
 
-
+def qc_masks(df) :
+    """Parse metadata of a QC bitmap and returns dict of meaning => mask"""
+    attrs = df.attrs["variables"][QC_FLAGS_VAR]
+    return {meaning: mask for meaning, mask in zip(
+        attrs["flag_meanings"].split(),
+        attrs["flag_masks"]
+    )}
 
 def parse_bool(value) :
     return value in ["true", "True", "1", "yes", "Yes"]
 
-
 def parallel_map(fn, iterable, parallel, max_workers=None) :
     """Helper util to map either seuquentially or in parallel """
     if parallel :
